==> netbeans_6.5.orig.tar.gz: netbeans-6.5/options.editor/src/org/netbeans/modules/options/generaleditor/GeneralEditorPanelController.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.modules.options.generaleditor;

import java.beans.PropertyChangeListener;
import javax.swing.JComponent;
import org.netbeans.spi.options.OptionsPanelController;
import org.openide.util.HelpCtx;
import org.openide.util.Lookup;


/**
 * Implementation of one panel in Options Dialog.
 *
 * @author Jan Jancura
 */
public final class GeneralEditorPanelController extends OptionsPanelController {

    public GeneralEditorPanelController() {
        
    }
    
    public void update () {
        getGeneralEditorPanel ().update ();
    }

    public void applyChanges () {
        getGeneralEditorPanel ().applyChanges ();
    }
    
    public void cancel () {
        getGeneralEditorPanel ().cancel ();
    }
    
    public boolean isValid () {
        return getGeneralEditorPanel ().dataValid ();
    }
    
    public boolean isChanged () {
        return getGeneralEditorPanel ().isChanged ();
    }
    
    public HelpCtx getHelpCtx () {
        return new HelpCtx ("netbeans.optionsDialog.editor.general");
    }
    
    public JComponent getComponent (Lookup masterLookup) {
        return getGeneralEditorPanel ();
    }

    public void addPropertyChangeListener (PropertyChangeListener l) {
        getGeneralEditorPanel ().addPropertyChangeListener (l);
    }

    public void removePropertyChangeListener (PropertyChangeListener l) {
        getGeneralEditorPanel ().removePropertyChangeListener (l);
    }
    
    
    private GeneralEditorPanel generalEditorPanel;
    
    private GeneralEditorPanel getGeneralEditorPanel () {
        if (generalEditorPanel == null)
            generalEditorPanel = new GeneralEditorPanel ();
        return generalEditorPanel;
    }
}

==> netbeans_6.8.orig.tar.gz: netbeans-6.8/options.editor/src/org/netbeans/modules/options/generaleditor/GeneralEditorPanelController.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.modules.options.generaleditor;

import java.beans.PropertyChangeListener;
import javax.swing.JComponent;
import org.netbeans.spi.options.OptionsPanelController;
import org.openide.util.HelpCtx;
import org.openide.util.Lookup;


/**
 * Implementation of one panel in Options Dialog.
 *
 * @author Jan Jancura
 */
@OptionsPanelController.SubRegistration(
    displayName="org.netbeans.modules.options.editor.Bundle#CTL_General_DisplayName",
    keywords="org.netbeans.modules.options.editor.Bundle#KW_General",
    keywordsCategory="Editor/General",
    id="General", // XXX used anywhere?
    location="Editor",
    position=100
//    toolTip="org.netbeans.modules.options.editor.Bundle#CTL_General_ToolTip"
)
public final class GeneralEditorPanelController extends OptionsPanelController {

    public void update () {
        getGeneralEditorPanel ().update ();
    }

    public void applyChanges () {
        getGeneralEditorPanel ().applyChanges ();
    }
    
    public void cancel () {
        getGeneralEditorPanel ().cancel ();
    }
    
    public boolean isValid () {
        return getGeneralEditorPanel ().dataValid ();
    }
    
    public boolean isChanged () {
        return getGeneralEditorPanel ().isChanged ();
    }
    
    public HelpCtx getHelpCtx () {
        return new HelpCtx ("netbeans.optionsDialog.editor.general");
    }
    
    public JComponent getComponent (Lookup masterLookup) {
        return getGeneralEditorPanel ();
    }

    public void addPropertyChangeListener (PropertyChangeListener l) {
        getGeneralEditorPanel ().addPropertyChangeListener (l);
    }

    public void removePropertyChangeListener (PropertyChangeListener l) {
        getGeneralEditorPanel ().removePropertyChangeListener (l);
    }
    
    
    private GeneralEditorPanel generalEditorPanel;
    
    private GeneralEditorPanel getGeneralEditorPanel () {
        if (generalEditorPanel == null)
            generalEditorPanel = new GeneralEditorPanel ();
        return generalEditorPanel;
    }
}
